""" VeraCore API Constants """


# ORDER STATUSES
ORDER_STATUS_UNPROCESSED = 'Unprocessed'
ORDER_STATUS_PROCESSED = 'Processed'
ORDER_STATUS_PARTIAL_SHIP = 'PartiallyShipped'
ORDER_STATUS_COMPLETED = 'Complete'
ORDER_STATUS_CANCELLED = 'Cancelled'
ORDER_STATUS_ALL = 'All'

ORDER_STATUSES = [
    ORDER_STATUS_UNPROCESSED,
    ORDER_STATUS_PROCESSED,
    ORDER_STATUS_PARTIAL_SHIP,
    ORDER_STATUS_COMPLETED,
    ORDER_STATUS_CANCELLED,
    ORDER_STATUS_ALL
]


# SHIPPING LABEL STATUSES
SHIPPING_LABEL_NONE = 'None'
SHIPPING_LABEL_EXISTS = 'Exists'
SHIPPING_LABEL_EXCEPT = 'Exception'

SHIPPING_LABEL_STATUSES = [
    SHIPPING_LABEL_NONE,
    SHIPPING_LABEL_EXISTS,
    SHIPPING_LABEL_EXCEPT
]
